@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 1.8.3+   2011/12/13
+ * Version: 1.8.3+   2012/04/01
  */
 
 #include <linux/version.h>
@@ -191,7 +191,11 @@ void ccs_load_policy(const char *filename)
 		envp[0] = "HOME=/";
 		envp[1] = "PATH=/sbin:/bin:/usr/sbin:/usr/bin";
 		envp[2] = NULL;
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 23) || defined(UMH_WAIT_PROC)
+		call_usermodehelper(argv[0], argv, envp, UMH_WAIT_PROC);
+#else
 		call_usermodehelper(argv[0], argv, envp, 1);
+#endif
 	}
 #elif defined(TASK_DEAD)
 	{
@@ -260,7 +264,7 @@ static int __ccs_search_binary_handler(struct linux_binprm *bprm,
 	 * /sbin/init. /sbin/ccs-init executes /etc/ccs/ccs-load-module to
 	 * load loadable kernel module. The loadable kernel module modifies
 	 * "struct ccsecurity_ops". Thus, we need to transfer control to
-	 * __ccs_search_binary_handler() in security/ccsecurity/domain.c
+	 * __ccs_search_binary_handler() in security/ccsecurity/permission.c
 	 * if "struct ccsecurity_ops" was modified.
 	 */
 	if (ccsecurity_ops.search_binary_handler
